# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      read_ini.py
# Author:       xxxxxxx
# Datetime:     2023/8/5 9:15
# Description:
# 
# ---------------------------------------------------------------------------
"""
读取ini文件的流程
    一。构造函数
        1.获取ini文件的路径
        2.获取存放文件的父目录
        3.使用configparser创建configparser对象
        4.使用对象的read方法读取ini文件
    二。方法
        1.使用对象的get方法获取对应节点下key对应的值
"""
import configparser
import os


class ReadIni:

    def __init__(self):
        # 获取存放文件的父级目录
        self.data_management_path = os.path.join(os.path.dirname(os.path.dirname(__file__)), "data_management")
        # 获取ini文件的目录
        ini_path = os.path.join(self.data_management_path, "config.ini")
        # 创建configparser的对象
        self.conf = configparser.ConfigParser()
        # 使用对象的read方法读取文件内容到对象中
        self.conf.read(ini_path, encoding='utf-8')

    # 根据key的值获取节点下对于文件的目录
    def read_file(self, key):
        value = self.conf.get("file", key)
        return os.path.join(self.data_management_path, value)

    # 根据key获取节点下host对应域名的值
    def read_host(self, key):
        return self.conf.get("host", key)

    # 根据key获取节点下excel表的表名
    def read_sheet(self, key):
        return self.conf.get("sheet_name", key)

    # 根据key获取节点下对应的数据库连接信息的值
    def read_sql(self, key):
        return self.conf.get("sql", key)


if __name__ == '__main__':
    read_ini = ReadIni()
    print(read_ini.read_sheet("sheet"))